@@ -1,6 +1,6 @@
 package App::ansicolumn;
 
-our $VERSION = "1.39";
+our $VERSION = "1.40";
 
 use v5.14;
 use warnings;
@@ -37,6 +37,7 @@ use Getopt::EX::Hashed 1.05; {
     has fillrows            => '    x    ' ;
     has table               => '    t    ' ;
     has table_columns_limit => ' =i l    ' , default => 0 ;
+    has table_align         => ' !    ca ' ;
     has table_right         => ' =s R    ' , default => '' ;
     has separator           => ' =s s    ' , default => ' ' ;
     has regex_sep           => '    r    ' ;
@@ -66,7 +67,7 @@ use Getopt::EX::Hashed 1.05; {
     has linebreak           => ' =s   lb ' , default => '' ;
     has runin               => ' =i      ' , min => 0, default => 2 ;
     has runout              => ' =i      ' , min => 0, default => 2 ;
-    has run                 => ' =i      ' ;
+    has runlen              => ' =i      ' ;
     has pagebreak           => ' !       ' , default => 1 ;
     has border              => ' :s      ' ; has B => '' , action => sub { $_->border = '' } ;
     has border_style        => ' =s   bs ' , default => 'box' ;
@@ -127,7 +128,12 @@ use Getopt::EX::Hashed 1.05; {
 	}
     };
 
-    ### --run
+    ### --runlen
+    has '+runlen' => sub {
+	$_->runin = $_->runout = $_[1];
+    };
+    # for backward compatibility, would be deplicated
+    has run => '=i';
     has '+run' => sub {
 	$_->runin = $_->runout = $_[1];
     };
@@ -515,11 +521,17 @@ sub table_out {
 			 [ map --$_, map {
 			     _numbers(max => int @max)->parse($_)->sequence
 			 } split /,/, $obj->table_right ] => '');
+    if ($obj->table_align) {
+	@max = map {
+	    roundup($_, $obj->column_unit, $obj->margin) - $obj->margin
+	} @max;
+	$obj->output_separator = ' ' x $obj->margin;
+    }
     my @format = map "%$align[$_]$max[$_]s", keys @max;
     for my $line (@lines) {
 	next unless @$line;
 	my @fmt = @format[keys @$line];
-	$fmt[$#{$line}] = '%s' if $align[$#{$line}] eq '-';
+	$fmt[$#fmt] = '%s' if $align[$#fmt] eq '-';
 	my $format = join $obj->output_separator, @fmt;
 	ansi_printf $format, @$line;
     } continue {
